nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

C0

Struct C0 

#[repr(transparent)]
pub struct C0(pub u32);
CMP Control Register 0

Tuple Fields

0: u32

Implementations

Source

impl C0

pub const fn hystctr(&self) -> Hystctr

Comparator hard block hysteresis control. See chip data sheet to get the actual hystersis value with each level

pub const fn set_hystctr(&mut self, val: Hystctr)

Comparator hard block hysteresis control. See chip data sheet to get the actual hystersis value with each level

pub const fn filter_cnt(&self) -> FilterCnt

Filter Sample Count

pub const fn set_filter_cnt(&mut self, val: FilterCnt)

Filter Sample Count

pub const fn en(&self) -> En

Comparator Module Enable

pub const fn set_en(&mut self, val: En)

Comparator Module Enable

pub const fn ope(&self) -> Ope

Comparator Output Pin Enable

pub const fn set_ope(&mut self, val: Ope)

Comparator Output Pin Enable

pub const fn cos(&self) -> Cos

Comparator Output Select

pub const fn set_cos(&mut self, val: Cos)

Comparator Output Select

pub const fn invt(&self) -> Invt

Comparator invert

pub const fn set_invt(&mut self, val: Invt)

Comparator invert

pub const fn pmode(&self) -> Pmode

Power Mode Select

pub const fn set_pmode(&mut self, val: Pmode)

Power Mode Select

pub const fn we(&self) -> We

Windowing Enable

pub const fn set_we(&mut self, val: We)

Windowing Enable

pub const fn se(&self) -> Se

Sample Enable

pub const fn set_se(&mut self, val: Se)

Sample Enable

pub const fn fpr(&self) -> u8

Filter Sample Period

pub const fn set_fpr(&mut self, val: u8)

Filter Sample Period

pub const fn cout(&self) -> bool

Analog Comparator Output

pub const fn set_cout(&mut self, val: bool)

Analog Comparator Output

pub const fn cff(&self) -> Cff

Analog Comparator Flag Falling

pub const fn set_cff(&mut self, val: Cff)

Analog Comparator Flag Falling

pub const fn cfr(&self) -> Cfr

Analog Comparator Flag Rising

pub const fn set_cfr(&mut self, val: Cfr)

Analog Comparator Flag Rising

pub const fn ief(&self) -> Ief

Comparator Interrupt Enable Falling

pub const fn set_ief(&mut self, val: Ief)

Comparator Interrupt Enable Falling

pub const fn ier(&self) -> Ier

Comparator Interrupt Enable Rising

pub const fn set_ier(&mut self, val: Ier)

Comparator Interrupt Enable Rising

pub const fn dmaen(&self) -> Dmaen

DMA Enable

pub const fn set_dmaen(&mut self, val: Dmaen)

DMA Enable

pub const fn linken(&self) -> Linken

CMP to DAC link enable.

pub const fn set_linken(&mut self, val: Linken)

CMP to DAC link enable.