#[repr(transparent)]pub struct Verid(pub u32);Expand description
Version ID Register
Tuple Fields
0: u32Implementations
Sourceimpl Verid
impl Verid
Sourcepub const fn feature(&self) -> u16
pub const fn feature(&self) -> u16
Feature Specification Number. This read only filed returns the feature set number.
Sourcepub const fn set_feature(&mut self, val: u16)
pub const fn set_feature(&mut self, val: u16)
Feature Specification Number. This read only filed returns the feature set number.
Sourcepub const fn minor(&self) -> u8
pub const fn minor(&self) -> u8
Minor Version Number. This read only field returns the minor version number for the module specification.
Sourcepub const fn set_minor(&mut self, val: u8)
pub const fn set_minor(&mut self, val: u8)
Minor Version Number. This read only field returns the minor version number for the module specification.