#[repr(transparent)]pub struct C0(pub u32);Expand description
CMP Control Register 0
Tuple Fields
0: u32Implementations
Sourceimpl C0
impl C0
Sourcepub const fn hystctr(&self) -> Hystctr
pub const fn hystctr(&self) -> Hystctr
Comparator hard block hysteresis control. See chip data sheet to get the actual hystersis value with each level
Sourcepub const fn set_hystctr(&mut self, val: Hystctr)
pub const fn set_hystctr(&mut self, val: Hystctr)
Comparator hard block hysteresis control. See chip data sheet to get the actual hystersis value with each level
Sourcepub const fn filter_cnt(&self) -> FilterCnt
pub const fn filter_cnt(&self) -> FilterCnt
Filter Sample Count
Sourcepub const fn set_filter_cnt(&mut self, val: FilterCnt)
pub const fn set_filter_cnt(&mut self, val: FilterCnt)
Filter Sample Count
Sourcepub const fn set_linken(&mut self, val: Linken)
pub const fn set_linken(&mut self, val: Linken)
CMP to DAC link enable.