#[repr(transparent)]pub struct RrTimerCr(pub u32);Expand description
Round-Robin Timer Control Register
Tuple Fields
0: u32Implementations
Sourceimpl RrTimerCr
impl RrTimerCr
Sourcepub const fn rr_timer_reload(&self) -> u32
pub const fn rr_timer_reload(&self) -> u32
This field establishes the repetitive count rate for the timer. Each time the timer counts down to zero it is reloaded with this value. The rr_trig signal will be generated at a rate of (rr_timer_reload + 1) times the rr_clock period (typically 30.6 uS)
Sourcepub const fn set_rr_timer_reload(&mut self, val: u32)
pub const fn set_rr_timer_reload(&mut self, val: u32)
This field establishes the repetitive count rate for the timer. Each time the timer counts down to zero it is reloaded with this value. The rr_trig signal will be generated at a rate of (rr_timer_reload + 1) times the rr_clock period (typically 30.6 uS)
Sourcepub const fn rr_timer_ena(&self) -> bool
pub const fn rr_timer_ena(&self) -> bool
RR_TIMER enable. When low, rr_timer count will be held at zero. When set, timer will commence continuous, repetitive counting beginning with the 1st or 2nd rising edge of the 32 KHz rr_clock.1
Sourcepub const fn set_rr_timer_ena(&mut self, val: bool)
pub const fn set_rr_timer_ena(&mut self, val: bool)
RR_TIMER enable. When low, rr_timer count will be held at zero. When set, timer will commence continuous, repetitive counting beginning with the 1st or 2nd rising edge of the 32 KHz rr_clock.1